%global		gituser		rizinorg
%global		gitname		rizin

%define		major		0
%define		libname		%mklibname %{name} %{major}
%define		develname	%mklibname %{name} -d
%define		shortversion	%(c=%{version}; echo ${c} | cut -d '.' -f -2)

Name:           rizin
Summary:        UNIX-like reverse engineering framework and command-line tool-set
Version:        0.7.4
Release:        %mkrel 2
License:        GPLv3+
Group:          System/Base
URL:            https://rizin.re/
Source0:        https://github.com/%{gituser}/%{gitname}/releases/download/v%{version}/%{name}-src-v%{version}.tar.xz

BuildRequires:  gcc
BuildRequires:  meson
BuildRequires:  ninja-build

BuildRequires:  pkgconfig(libmagic)
BuildRequires:  pkgconfig(libxxhash)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(capstone) >= 3.0.4
BuildRequires:  pkgconfig(libmspack)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libuv)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(tree-sitter)
BuildRequires:  python3dist(pyyaml)

Requires:       %{name}-common = %{version}-%{release}

# ./shlr/spp/README.md
# SPP stands for Simple Pre-Processor, a templating language.
# https://github.com/rizinorg/spp
Provides:       bundled(spp) = 1.2.0

# ./shlr/sdb/README.md
# sdb is a simple string key/value database based on djb's cdb
# https://github.com/rizinorg/sdb
Provides:       bundled(sdb) = db7edd4a96a89b6749b677a85d7fa4ee2c6fbbb9

# librz/util/regex/README
# Modified OpenBSD regex to be portable
# cvs -qd anoncvs@anoncvs.ca.openbsd.org:/cvs get -P src/lib/libc/regex
# version from 2010/11/21 00:02:30, version of files ranges from v1.11 to v1.20
Provides:       bundled(openbsdregex) = 1.11

# ./librz/asm/arch/tricore/README.md
# Based on code from https://www.hightec-rt.com/en/downloads/sources/14-sources-for-tricore-v3-3-7-9-binutils-1.html
# part of binutils to read machine code for Tricore architecture
# ./librz/asm/arch/ppc/gnu/
# part of binutils to read machine code for ppc architecture
# ./librz/asm/arch/arm/gnu/
Provides:       bundled(binutils) = 2.13

# ./librz/asm/arch/avr/README
# * This code has been ripped from vavrdisasm 1.6
Provides:       bundled(vavrdisasm) = 1.6

# rizin-v0.5.0/subprojects/blake3
# url = https://github.com/BLAKE3-team/BLAKE3.git
# revision = f84636e59ce575e5dd127399e0c7de0c1ea595da
Provides:       bundled(blake3) = 1.3.1

%description
Rizin is a free and open-source Reverse Engineering framework, providing a
complete binary analysis experience with features like Disassembler,
Hexadecimal editor, Emulation, Binary inspection, Debugger, and more.

Rizin is a fork of radare2 with a focus on usability, working features and code
cleanliness.

%files
%doc CONTRIBUTING.md DEVELOPERS.md README.md
%doc SECURITY.md BUILDING.md
%license COPYING COPYING.LESSER
%{_bindir}/r*
%{_mandir}/man1/rizin.1.*
%{_mandir}/man1/rz*.1.*
%{_mandir}/man7/rz-esil.7.*

#------------------------------------------------------------------------------

%package -n     %{libname}
Summary:        A library for %{name}
Group:          System/Libraries

%description -n %{libname}
Rizin is a free and open-source Reverse Engineering framework, providing a
complete binary analysis experience with features like Disassembler,
Hexadecimal editor, Emulation, Binary inspection, Debugger, and more.

Rizin is a fork of radare2 with a focus on usability, working features and code
cleanliness.

%files -n     %{libname}
%{_libdir}/librz_*.so.%{version}*
%{_libdir}/librz_*.so.%{shortversion}

#------------------------------------------------------------------------------

%package  -n %develname
Summary:        Development files for the rizin package
Group:          Development/Tools
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}

%description  -n %develname
Development files for the rizin package. See rizin package for more
information.

%files  -n %develname
%{_includedir}/librz
%{_libdir}/librz*.so
%{_libdir}/pkgconfig/*.pc
%{_libdir}/cmake/**/*.cmake
%dir %{_libdir}/cmake/**

#------------------------------------------------------------------------------

%package common
Summary:        Arch-independent SDB files for the rizin package
Group:          Development/Tools
BuildArch:      noarch
Requires:       %{name} >= %{version}-%{release}

%description common
Arch-independent SDB files used by rizin package. See rizin package for more
information

%files common
%{_datadir}/%{name}/asm
%{_datadir}/%{name}/cons
%{_datadir}/%{name}/flag
%{_datadir}/%{name}/format
%{_datadir}/%{name}/fortunes
%{_datadir}/%{name}/hud
%{_datadir}/%{name}/magic
%{_datadir}/%{name}/opcodes
%{_datadir}/%{name}/reg
%{_datadir}/%{name}/syscall
%{_datadir}/%{name}/types
%dir %{_datadir}/%{name}

%prep
# Build from git release version
%setup -q -n %{gitname}-v%{version}

%build
# Whereever possible use the system-wide libraries instead of bundles
%meson \
    -Duse_sys_magic=enabled \
    -Duse_sys_libzip=enabled \
    -Duse_sys_zlib=enabled \
    -Duse_sys_lz4=enabled \
    -Duse_sys_xxhash=enabled \
    -Duse_sys_openssl=enabled \
    -Duse_sys_capstone=enabled \
    -Duse_sys_tree_sitter=enabled \
    -Duse_sys_lzma=enabled \
    -Duse_sys_libmspack=enabled \
    -Duse_sys_libzstd=enabled \
%ifarch s390x
    -Ddebugger=false \
%endif
    -Denable_tests=false \
    -Denable_rz_test=false \
    -Dlocal=disabled \
    -Dpackager="%{_vendor}" \
    -Dpackager_version="%{version}-%{release}"
%meson_build

%install
%meson_install

%check
# Do not run the unit testsuite yet - it pulls another big repository
# https://github.com/rizinorg/rizin-testbins from github


%changelog
* Mon Feb 24 2025 daviddavid <daviddavid> 0.7.4-2.mga10
+ Revision: 2151890
- rebuild for new tree-sitter 0.25.2

* Wed Jan 08 2025 daviddavid <daviddavid> 0.7.4-1.mga10
+ Revision: 2136149
- new version: 0.7.4

* Sat Oct 05 2024 kekepower <kekepower> 0.7.3-3.mga10
+ Revision: 2103416
- Rebuild for new tree-sitter

* Wed Aug 28 2024 daviddavid <daviddavid> 0.7.3-2.mga10
+ Revision: 2092017
- rebuild for new tree-sitter 0.23.0

* Sun Apr 21 2024 daviddavid <daviddavid> 0.7.3-1.mga10
+ Revision: 2060214
- new version: 0.7.3

* Wed Jan 24 2024 daviddavid <daviddavid> 0.6.3-2.mga10
+ Revision: 2034111
- enable system lzma, libmspack and tree-sitter

* Wed Jan 24 2024 daviddavid <daviddavid> 0.6.3-1.mga10
+ Revision: 2034102
- new version: 0.6.3

* Mon Dec 11 2023 tv <tv> 0.5.2-2.mga10
+ Revision: 2017185
- Rebuild for capstone-5

* Wed Jun 28 2023 papoteur <papoteur> 0.5.2-1.mga9
+ Revision: 1963252
- new 0.5.2 (mga#31743, CVE-2022-34612, CVE-2022-36039, CVE-2022-3604[0-4], CVE-2023-27590)

* Sun Jan 08 2023 daviddavid <daviddavid> 0.4.1-1.mga9
+ Revision: 1931604
- new version: 0.4.1

* Mon Jan 02 2023 daviddavid <daviddavid> 0.4.0-2.mga9
+ Revision: 1929338
- devel sub pkg require lib sub pkg
- relax common dependency

* Sat Aug 13 2022 pol4n <pol4n> 0.4.0-1.mga9
+ Revision: 1877320
- Update to 0.4.0

* Fri Apr 01 2022 umeabot <umeabot> 0.3.1-2.mga9
+ Revision: 1838988
- Mageia 9 Mass Rebuild

* Sun Jan 02 2022 neoclust <neoclust> 0.3.1-1.mga9
+ Revision: 1766265
- imported package rizin


* Mon Nov 29 2021 Riccardo Schirone <rschirone91@gmail.com> - 0.3.1-1
- Rebase to upstream version 0.3.1

* Mon Sep 27 2021 Riccardo Schirone <rschirone91@gmail.com> - 0.3.0-1
- Rebase to upstream version 0.3.0

* Tue Sep 14 2021 Sahana Prasad <sahana@redhat.com> - 0.2.0-2.2
- Rebuilt with OpenSSL 3.0.0

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.2.0-2.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Tue Apr 20 2021 Riccardo Schirone <rschirone91@gmail.com> - 0.2.0-2
- Apply patch to avoid symbols collision

* Mon Apr 12 2021 Riccardo Schirone <rschirone91@gmail.com> - 0.2.0-1
- Rebase to upstream version 0.2.0

* Tue Mar 30 2021 Riccardo Schirone <rschirone91@gmail.com> - 0.1.2-1
- Initial SPEC file
